@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 import pytest
 
@@ -155,6 +155,12 @@ class TestColDimension:
         assert dict(cd1) == dict(cd2)
 
 
+    def test_no_named_style(self, ColumnDimension):
+        cd = ColumnDimension(worksheet=DummyWorksheet())
+        with pytest.raises(AttributeError):
+            cd.style = "Normal"
+
+
 class TestGrouping:
 
     def test_group_columns_simple(self):
@@ -183,3 +189,28 @@ class TestGrouping:
         dh = DimensionHolder(None)
         node = dh.to_tree()
         assert node is None
+
+    def test_group_rows_simple(self):
+        from ..worksheet import Worksheet
+        ws = Worksheet(DummyWorkbook())
+        dims = ws.row_dimensions
+        dims.group(1, 5, 1)
+        assert len(dims) == 5
+        group = list(dims.values())[0]
+        assert group.outline_level == 1
+
+
+    def test_group_rows_collapse(self):
+        from ..worksheet import Worksheet
+        ws = Worksheet(DummyWorkbook())
+        dims = ws.row_dimensions
+        dims.group(1, 10, 1, hidden=True)
+        group = list(dims.values())[5]
+        assert group.hidden
+
+
+    def test_no_rows(self):
+        from ..dimensions import DimensionHolder
+        dh = DimensionHolder(None)
+        node = dh.to_tree()
+        assert node is None
\ No newline at end of file
